#[unsafe(no_mangle)]pub extern "C" fn getpriority(which: c_int, who: id_t) -> c_intExpand description
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/getpriority.html.
Obtains the nice value of a process, process group or user.
A value of 0 for who indicates the current process, process group or
user.
A return value of -1 can either be a valid nice value or indicate that
an error occurred. To distinguish between them, first set errno to 0
before calling getpriority(), then check the value of errno after the
call to getpriority().