getrlimit

Function getrlimit 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn getrlimit( resource: c_int, rlp: *mut rlimit, ) -> c_int
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/getrlimit.html.

Stores the value of the limit indicated by resource into the rlimit struct pointed to by rlp.

A return value of 0 indicates success, -1 indicates error.