getrusage

Function getrusage 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn getrusage( who: c_int, r_usage: *mut rusage, ) -> c_int
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/getrusage.html.

Stores the measures of the resources used by the current process or its terminated and waited-for child processes in the rusage struct pointed to by r_usage.

A return value of 0 indicates success, -1 indicates error.