setpriority

Function setpriority 

#[unsafe(no_mangle)]
pub extern "C" fn setpriority( which: c_int, who: id_t, nice: c_int, ) -> c_int
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/setpriority.html.

Sets the nice value of a process, process group or user.

A value of 0 for who indicates the current process, process group or user.

A return value of 0 indicates success, -1 indicates error.