setrlimit

Function setrlimit 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn setrlimit( resource: c_int, rlp: *const rlimit, ) -> c_int
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/setrlimit.html.

Sets the value of the limit indicated by resource to the value specified in the rlimit struct pointed to by rlp.

A return value of 0 indicates success, -1 indicates error.